@@ -26,12 +26,12 @@ def build_config() -> dict[str, str]:
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-jisn2k94/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy/lib/contourpy/util",
+        build_dir=r"/startdir/src/contourpy/.mesonpy-5cqu_82w/lib/contourpy/util",
+        source_dir=r"/startdir/src/contourpy/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-jisn2k94/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/startdir/src/contourpy/.mesonpy-5cqu_82w/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
